"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SContractPersistent = void 0;

var _utilCrypto = require("@polkadot/util-crypto");

var _fs = _interopRequireDefault(require("fs"));

var _crypto = require("@skyekiwi/crypto");

var _driver = require("@skyekiwi/driver");

var _file = require("@skyekiwi/file");

var _ipfs = require("@skyekiwi/ipfs");

var _secretRegistry = require("@skyekiwi/secret-registry");

var _util = require("@skyekiwi/util");

var _reader = require("./reader.cjs");

// Copyright 2021-2022 @skyekiwi/s-contract authors & contributors
// SPDX-License-Identifier: Apache-2.0

/* eslint-disable */
require('dotenv').config();
/* eslint-enable */


class SContractPersistent {
  static async initialize(config, contractId, wasmBlobCID) {
    if (!process.env.SEED_PHRASE) {
      throw new Error('seed phrase not found, aborting - s-contract/initialize');
    }

    const outputPath = `${config.localStoragePath}`;
    const sealer = new _crypto.DefaultSealer();
    const registry = new _secretRegistry.SecretRegistry(process.env.SEED_PHRASE, {});
    sealer.unlock((0, _utilCrypto.mnemonicToMiniSecret)(process.env.SEED_PHRASE));
    await _driver.Driver.downstream((0, _util.stringToIndex)(contractId), [(0, _utilCrypto.mnemonicToMiniSecret)(process.env.SEED_PHRASE)], registry, _fs.default.createWriteStream(outputPath + `${contractId}.contract`), sealer);
    const ipfs = new _ipfs.IPFS();
    const wasmBlob = await ipfs.cat(wasmBlobCID);
    const wasmPath = outputPath + `${contractId}.wasm`;
    await _file.File.writeFile(Buffer.from((0, _util.hexToU8a)(wasmBlob)), wasmPath, 'w');
    const sContract = new _reader.SContractReader(new _file.File({
      fileName: contractId,
      readStream: _fs.default.createReadStream(outputPath + `${contractId}.contract`)
    }), sealer);
    await sContract.init();
    await registry.disconnect();
    return sContract;
  }

  static async rollup(config, instance) {
    if (!process.env.SEED_PHRASE) {
      throw new Error('seed phrase not found, aborting - s-contract/initialize');
    }

    const outputPath = `${config.localStoragePath}`;
    const contractId = instance.getContractId();
    const sealer = new _crypto.DefaultSealer();
    const registry = new _secretRegistry.SecretRegistry(process.env.SEED_PHRASE, {});
    sealer.unlock((0, _utilCrypto.mnemonicToMiniSecret)(process.env.SEED_PHRASE));
    await instance.writeToFile(outputPath + `${contractId}.contract`);
    const contractFile = new _file.File({
      fileName: instance.getContractId(),
      readStream: _fs.default.createReadStream(outputPath + `${contractId}.contract`)
    });
    const encryptionSchema = new _crypto.EncryptionSchema();
    encryptionSchema.addMember(sealer.getAuthorKey());
    const result = await _driver.Driver.upstream(contractFile, sealer, encryptionSchema, registry);
    await registry.disconnect();
    return result;
  }

}

exports.SContractPersistent = SContractPersistent;